//1.1.1
// Purpose of script: To run on server and create and refill a set of ammoboxes;
// Argument structure: [Array,String,Array,Array,bool,bool]
// Argument 1: Array: [Array,Array,...]
//	Subarray: [String,String,Array,Array,bool**]
//		String: Name of marker where to place box
//		String: Name of the ammo box class 
//		Subarray: [String,Int]
//			String: Name of a weapon class to put in the box
//			Int: Number of weapons to place in box
//		Subarray: [String,Int]
//			String: Name of a magazine class to put in the box
//			Int: Number of magazines to place in box
//		Bool**: OPTIONAL! Overrides Arguemnt 3 if set activates an override function. If true THIS box will always be completly emptied before being restocked.
//				
// Argument 2: Bool. Clear box of original content
// Argument 3: Bool. Respawn destroyed boxes
// Argument 3: Bool. Allways clear boxes of extra content before restocking
//
//Example 1:[[["ammo1","CZBasicWeapons_EP1",[["AK_74_GL",10],["Strela",40]],[["30Rnd_545x39_AK",5],["Strela",10]]],["ammo2","CZBasicWeapons_EP1",[["AK_74_GL",10],["Strela",40]],[["30Rnd_545x39_AK",5] , ["Strela",10]]]],false, true, true] execVM "ammoboxrespawn.sqf";
//Example 2:
//	_allboxes = [];
//	_box_marker 	= "ammo1";
//	_box_boxmodel	="CZBasicWeapons_EP1";
//	_box_weapon1	=["AK_74_GL",10];
//	_box_weapon2	=["Strela",10];
//	_box_allWeapons	=[_box_weapon1,_box_weapon2];
//	_box_ammo1		=["30Rnd_545x39_AK",5];
//	_box_ammo2		=["Strela",10];
//	_box_allAmmo	=[_box_ammo1,_box_ammo2]; 
//	_box			=[_box_marker,_box_boxmodel,_box_allWeapons,_box_allAmmo];
//	_allboxes	= _allboxes +[_box];
//	[_allboxes,true,false,false] execVM "ammoboxrespawn.sqf";
	
	
if !(isServer || isDedicated) exitWith {};

_boxesToSetUp=_this select 0;						//Array of strings (map marker names)
_removeAllDefaultContent=_this select 1; 			//bool (If true: Creates an empty box and only fills it with the content supplied as variables)
_respawnDestroyedBoxes=_this select 2; 				//bool (If true: Destroyed ammo boxes are replaced)
_clearExtraContent=_this select 3; 					//bool (If true: Removes ALL content of box before refilling)

_refeill_timer = 120;								//Time between box refils, in seconds.
_scriptRunTime=time;

//function
_createbox = {
	_ammoInbox=[];
	_weaponsInbox=[];
	//Create box and store it among boxes
	_box=createVehicle [(_this select 1), (getMarkerPos (_this select 0)), [], 0, "CAN_COLLIDE"];
	
	//Content
	//Clear content?
	if(_removeAllDefaultContent) then {
		clearWeaponCargoGlobal _box;
		clearMagazineCargoGlobal _box;
	};
	//add extra weapons and ammo
	{
		_box addWeaponCargoGlobal [_x select 0,_x select 1];
	} foreach (_this select 2);
	{
		_box addMagazineCargoGlobal [_x select 0,_x select 1];
	} foreach (_this select 3);
	_contentA=getMagazineCargo _box;
	_contentW=getWeaponCargo _box;
	
	
	{
		_ammoInbox=_ammoInbox +[[_x,((_contentA select 1) select _forEachIndex)]];
	}forEach (_contentA select 0);
	
	{
		_weaponsInbox=_weaponsInbox +[[_x,((_contentW select 1) select _forEachIndex)]];
	}forEach (_contentW select 0);
	
	_boxes set [_this select 4,_box];
	_contentList_ammoInboxes set [_this select 4,_ammoInbox];
	_contentList_weaponsInboxes set [_this select 4,_weaponsInbox];
};


_boxes=[];
_contentList_ammoInboxes=[];
_contentList_weaponsInboxes=[];

_boxesContents=[];
{
	_marker		= _x select 0;
	_boxType	= _x select 1;
	_addWeapon	= _x select 2;
	_addAmmo	= _x select 3;
	_index		= _forEachIndex;
	[_marker,_boxType,_addWeapon,_addAmmo,_index] call _createbox;
} forEach _boxesToSetUp;







while {count _boxes > 0} do{
	_scriptRunTime=_scriptRunTime+_refeill_timer;
	while{_scriptRunTime>time} do {sleep 1;};
	{
		_box= _x;
		_clearCargo= _clearExtraContent;
		_check=(_boxesToSetUp select _forEachIndex) select 4;
		if(!isNil("_check")) then {_clearCargo=_check;};
		if (_clearCargo) then {
			clearWeaponCargoGlobal _box;
			clearMagazineCargoGlobal _box;
		};
		
		//if box is not destroyed refil
		if(alive _box) then {
			//add magazines where needed
			_thisBox_contentList=_contentList_ammoInboxes select _forEachIndex;
			{
				_contentListItem=_x select 0;
				_contentListAmount=_x select 1;
				_currentItemsAndAmountsInBoxArrays=getMagazineCargo _box;
				_currentItemsInbox_List	= _currentItemsAndAmountsInBoxArrays select 0;
				_currentAmmoInbox_amountList = _currentItemsAndAmountsInBoxArrays select 1;
				_ammountToAdd=_contentListAmount;
				for[{_i=0},{_i<count _currentItemsInbox_List},{_i=_i+1}] do {
					_itemInBox_item 	= _currentItemsInbox_List select _i;
					_itemInBox_amount	= _currentAmmoInbox_amountList select _i;
					if(_contentListItem == _itemInBox_item )then {
						_ammountToAdd=_ammountToAdd-_itemInBox_amount;
						_i=count _currentItemsInbox_List;
					};
				};
				if (_ammountToAdd > 0) then {
					_box addMagazineCargoGlobal [_contentListItem,_ammountToAdd];
				};
			}forEach _thisBox_contentList;
			
			
			//add weapons where needed
			_thisBox_contentList=_contentList_weaponsInboxes select _forEachIndex;
			{
				_contentListItem=_x select 0;
				_contentListAmount=_x select 1;
				_currentItemsAndAmountsInBoxArrays=getWeaponCargo _box;
				_currentItemsInbox_List	= _currentItemsAndAmountsInBoxArrays select 0;
				_currentAmmoInbox_amountList = _currentItemsAndAmountsInBoxArrays select 1;
				_ammountToAdd=_contentListAmount;
				for[{_i=0},{_i<count _currentItemsInbox_List},{_i=_i+1}] do {
					_itemInBox_item 	= _currentItemsInbox_List select _i;
					_itemInBox_amount	= _currentAmmoInbox_amountList select _i;
					if(_contentListItem == _itemInBox_item )then {
						_ammountToAdd=_ammountToAdd-_itemInBox_amount;
						_i=count _currentItemsInbox_List;
					};
				};
				if (_ammountToAdd > 0) then {
					_box addWeaponCargoGlobal [_contentListItem,_ammountToAdd];
				};
			}forEach _thisBox_contentList;

		}else{
			//if box is destroyed
			//Respawn
			if (_respawnDestroyedBoxes) then {
				_marker		= (_boxesToSetUp select _forEachIndex) select 0;
				_boxType	= (_boxesToSetUp select _forEachIndex) select 1;
				_addWeapon	= (_boxesToSetUp select _forEachIndex) select 2;
				_addAmmo	= (_boxesToSetUp select _forEachIndex) select 3;
				_index		= _forEachIndex;
				_array		= [_marker,_boxType,_addWeapon,_addAmmo,_index];
				_array call _createbox;
			}else{
			//no respawn, remove
				_boxes set [_forEachIndex,0];
				_contentList_ammoInboxes set [_forEachIndex,0];
				_contentList_weaponsInboxes set [_forEachIndex,0];
			};
		};
	} foreach _boxes;
	
	//remove deleted boxes
	_boxes = _boxes - [0];
	_contentList_ammoInboxes = _contentList_ammoInboxes - [0];
	_contentList_weaponsInboxes = _contentList_weaponsInboxes - [0];
};